gchecky.model.alternate_tax_table_t

Package gchecky :: Module model :: Class alternate_tax_table_t |
[hide private]
[frames] | no frames]

# Class alternate_tax_table_t

source code

    object --+
             |
     gxml.Node --+
                 |
                alternate_tax_table_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| name = `String:PATH(@name):REQ:EMPTY`
| standalone = `gxml.Boolean('@standalone')`
| alternate_tax_rules = `List:PATH(alternate-tax-rules):RE`...``
| _fields = ``{``'``alternate_tax_rules``'``:` List:PATH(alternate-tax-rule`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### alternate_tax_rules Value:
      List:PATH(alternate-tax-rules):REQ:[
          Node:PATH(alternate-tax-rule):REQ:{ alternate_tax_rule_t }
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'alternate_tax_rules': List:PATH(alternate-tax-rules):REQ:[
          Node:PATH(alternate-tax-rule):REQ:{ alternate_tax_rule_t }
      ],
       'name': String:PATH(@name):REQ:EMPTY,
       'standalone': ??}